# Core API

This page documents the core API of pydapter.

## Core Module

::: pydapter.core options: show_root_heading: true show_source: true

## Async Core Module

::: pydapter.async_core options: show_root_heading: true show_source: true

## Exceptions

::: pydapter.exceptions options: show_root_heading: true show_source: true
